@@ -7,7 +7,7 @@ use warnings;
 
 use base 'Mojo::Script';
 
-use Mojo::Server::Daemon::Prefork;
+use Curse::Server::Daemon::Prefork;
 
 __PACKAGE__->attr('description', chained => 1, default => <<'EOF');
 * Start the prefork daemon. *
@@ -23,8 +23,9 @@ sub run {
     my ($self, $port) = @_;
 
     # Start server
-    my $daemon = Mojo::Server::Daemon::Prefork->new;
+    my $daemon = Curse::Server::Daemon::Prefork->new;
     $daemon->port($port) if $port;
+    $daemon->debug(1);
     $daemon->run;
 
     return $self;
@@ -35,19 +36,18 @@ __END__
 
 =head1 NAME
 
-Mojo::Script::DaemonPrefork - Prefork Daemon Script
+Mojo::Script::Daemon::Prefork - Prefork Daemon Script
 
 =head1 SYNOPSIS
 
     use Mojo::Script::Daemon::Prefork;
-
     my $daemon = Mojo::Script::Daemon::Prefork->new;
     $daemon->run(@ARGV);
 
 =head1 DESCRIPTION
 
-L<Mojo::Script::Daemon::Prefork> is a script interface to
-L<Mojo::Server::Daemon::Prefork>.
+L<Mojo::Script::Daemon::Prefork> is a simple script interface to
+L<Curse::Server::Daemon::Prefork>.
 
 =head1 ATTRIBUTES
 
